==> simplex2-4.7.x-1.0.tar.gz: simplex2/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
        "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language ?>" xml:lang="<?php print $language ?>">

  <head>
    <title><?php print $head_title ?></title>
    <meta http-equiv="Content-Style-Type" content="text/css" />
    <?php print $head ?>
    <?php print $styles ?>
  </head>

<body <?php print theme("onload_attribute"); ?>>
  <div id="main">

   <?php if (count($primary_links)) : ?>
     <div id="topmenu">
     <?php foreach ($primary_links as $link): ?>
       <?php print $link?>
     <?php endforeach; ?>
     </div>
   <?php endif; ?>
   <?php if (count($secondary_links)) : ?>
     <div id="topmenu-secondary">
     <?php foreach ($secondary_links as $link): ?>
       <?php print $link?>
     <?php endforeach; ?>
     </div>
   <?php endif; ?>

    <?php if ($site_name) : ?>
        <div id="header">
          <span class="head-title"><a href="<?php print $base_path ?>" title="<?php print t('Home') ?>"><?php print(substr($site_name, 0, 1)) ?><span class="head-darktitle"><?php print(substr($site_name,1,strlen($site_name)-1)) ?></span></a></span><br/>
        </div>
    <?php endif;?>

    <div id="lefty">
      <?php if ($sidebar_left) { ?>
        <?php print $sidebar_left ?>
      <?php } ?>
      <?php if ($sidebar_right != ""): ?>
        <?php print $sidebar_right ?> <!-- print right sidebar if any blocks enabled -->
      <?php endif; ?> 
  
    </div>

    <div id="content">
      <div id="breadcrumb">
       <?php print $breadcrumb ?>
      </div>

      <?php if ($mission) { ?><div id="mission"><?php print $mission ?></div><?php } ?>
      <?php print $help ?>
      <?php print $messages ?>

      <h1 class="title"><?php print $title ?></h1>
      <div class="tabs"><?php print $tabs ?></div>

      <?php print $content; ?>

      <div id="footer">
        <?php print $footer_message ?>
      </div>
      <?php print $closure ?>

    </div>

</div>


</body>
</html>

==> simplex2-5.x-1.1.tar.gz: simplex2/page.tpl.php <==
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
        "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" lang="<?php print $language ?>" xml:lang="<?php print $language ?>">

  <head>
    <title><?php print $head_title ?></title>
    <meta http-equiv="Content-Style-Type" content="text/css" />
	<?php print $head ?>
	<?php print $styles ?>
	<?php print $scripts ?>
	<script type="text/javascript"><?php /* Needed to avoid Flash of Unstyle Content in IE */ ?> </script>
  </head>

<body>
  <div id="main">

   <?php if (count($primary_links)) : ?>
     <div id="topmenu">
     <?php print theme('links', $primary_links); ?>
     </div>
   <?php endif; ?>
   <?php if (count($secondary_links)) : ?>
     <div id="topmenu-secondary">
     <?php print theme('links', $secondary_links); ?>
     </div>
   <?php endif; ?>

    <?php if ($site_name) : ?>
        <div id="header">
          <span class="head-title"><?php print(substr($site_name, 0, 1)) ?><span class="head-darktitle"><?php print(substr($site_name,1,15)) ?></span></span><br/>
        </div>
    <?php endif;?>

    <div id="lefty">
      <?php if ($sidebar_left) { ?>
        <?php print $sidebar_left ?>
      <?php } ?>
      <?php if ($sidebar_right != ""): ?>
        <?php print $sidebar_right ?> <!-- only print right sidebar if any blocks enabled -->
      <?php endif; ?> 
  
    </div>

    <div id="content">
      <div id="breadcrumb">
       <?php print $breadcrumb ?>
      </div>

      <?php if ($mission) { ?><div id="mission"><?php print $mission ?></div><?php } ?>
      <?php print $help ?>
      <?php print $messages ?>

      <h1 class="title"><?php print $title ?></h1>
      <div class="tabs"><?php print $tabs ?></div>

      <?php print $content; ?>

      <div id="footer">
        <?php print $footer_message ?>
      </div>
      <?php print $closure ?>

    </div>

</div>


</body>
</html>
